@@ -14,10 +14,10 @@ $config = array(
      * [(http|https)://(hostname|fqdn)[:port]]/[path/to/simplesaml/]
      * (note that it must end with a '/')
      *
-     * The full url format is useful if your simpleSAMLphp setup is hosted behind
+     * The full url format is useful if your SimpleSAMLphp setup is hosted behind
      * a reverse proxy. In that case you can specify the external url here.
      *
-     * Please note that simpleSAMLphp will then redirect all queries to the
+     * Please note that SimpleSAMLphp will then redirect all queries to the
      * external url, no matter where you come from (direct access or via the
      * reverse proxy).
      */
@@ -27,7 +27,7 @@ $config = array(
     'datadir' => 'data/',
 
     /*
-     * A directory where simpleSAMLphp can save temporary files.
+     * A directory where SimpleSAMLphp can save temporary files.
      *
      * SimpleSAMLphp will attempt to create this directory if it doesn't exist.
      */
@@ -35,7 +35,7 @@ $config = array(
 
 
     /*
-     * If you enable this option, simpleSAMLphp will log all sent and received messages
+     * If you enable this option, SimpleSAMLphp will log all sent and received messages
      * to the log file.
      *
      * This option also enables logging of the messages that are encrypted and decrypted.
@@ -71,7 +71,7 @@ $config = array(
 
     /**
      * This password must be kept secret, and modified from the default value 123.
-     * This password will give access to the installation page of simpleSAMLphp with
+     * This password will give access to the installation page of SimpleSAMLphp with
      * metadata listing and diagnostics pages.
      * You can also put a hash here; run "bin/pwgen.php" to generate one.
      */
@@ -80,7 +80,7 @@ $config = array(
     'admin.protectmetadata' => false,
 
     /**
-     * This is a secret salt used by simpleSAMLphp when it needs to generate a secure hash
+     * This is a secret salt used by SimpleSAMLphp when it needs to generate a secure hash
      * of a value. It must be changed from its default value to a secret value. The value of
      * 'secretsalt' can be any valid string of any length.
      *
@@ -99,7 +99,7 @@ $config = array(
 
     /*
      * The timezone of the server. This option should be set to the timezone you want
-     * simpleSAMLphp to report the time in. The default is to guess the timezone based
+     * SimpleSAMLphp to report the time in. The default is to guess the timezone based
      * on your system timezone.
      *
      * See this page for a list of valid timezones: http://php.net/manual/en/timezones.php
@@ -114,7 +114,7 @@ $config = array(
      *		SimpleSAML_Logger::WARNING	No statistics, only warnings/errors
      *		SimpleSAML_Logger::NOTICE	Statistics and errors
      *		SimpleSAML_Logger::INFO		Verbose logs
-     *		SimpleSAML_Logger::DEBUG	Full debug logs - not reccomended for production
+     *		SimpleSAML_Logger::DEBUG	Full debug logs - not recommended for production
      *
      * Choose logging handler.
      *
@@ -155,7 +155,7 @@ $config = array(
     /*
      * Choose which facility should be used when logging with syslog.
      *
-     * These can be used for filtering the syslog output from simpleSAMLphp into its
+     * These can be used for filtering the syslog output from SimpleSAMLphp into its
      * own file by configuring the syslog daemon.
      *
      * See the documentation for openlog (http://php.net/manual/en/function.openlog.php) for available
@@ -197,10 +197,65 @@ $config = array(
     ),
 
 
+
+    /*
+     * Database
+     *
+     * This database configuration is optional. If you are not using
+     * core functionality or modules that require a database, you can
+     * skip this configuration.
+     */
+
+    /*
+     * Database connection string.
+     * Ensure that you have the required PDO database driver installed
+     * for your connection string.
+     */
+    'database.dsn' => 'mysql:host=localhost;dbname=saml',
+
+    /*
+     * SQL database credentials
+     */
+    'database.username' => 'simplesamlphp',
+    'database.password' => 'secret',
+
+    /*
+     * (Optional) Table prefix
+     */
+    'database.prefix' => '',
+
+    /*
+     * True or false if you would like a persistent database connection
+     */
+    'database.persistent' => false,
+
+    /*
+     * Database slave configuration is optional as well. If you are only
+     * running a single database server, leave this blank. If you have
+     * a master/slave configuration, you can define as many slave servers
+     * as you want here. Slaves will be picked at random to be queried from.
+     *
+     * Configuration options in the slave array are exactly the same as the
+     * options for the master (shown above) with the exception of the table
+     * prefix.
+     */
+    'database.slaves' => array(
+        /*
+        array(
+            'dsn' => 'mysql:host=myslave;dbname=saml',
+            'username' => 'simplesamlphp',
+            'password' => 'secret',
+            'persistent' => false,
+        ),
+        */
+    ),
+
+
+
     /*
      * Enable
      *
-     * Which functionality in simpleSAMLphp do you want to enable. Normally you would enable only
+     * Which functionality in SimpleSAMLphp do you want to enable. Normally you would enable only
      * one of the functionalities below, but in some cases you could run multiple functionalities.
      * In example when you are setting up a federation bridge.
      */
@@ -292,12 +347,6 @@ $config = array(
      */
     'session.cookie.secure' => false,
 
-    /*
-     * When set to FALSE fallback to transient session on session initialization
-     * failure, throw exception otherwise.
-     */
-    'session.disable_fallback' => false,
-
     /*
      * Enable secure POST from HTTPS to HTTP.
      *
@@ -316,7 +365,7 @@ $config = array(
      */
     'session.phpsession.cookiename' => null,
     'session.phpsession.savepath' => null,
-    'session.phpsession.httponly' => false,
+    'session.phpsession.httponly' => true,
 
     /*
      * Option to override the default settings for the auth token cookie
@@ -447,7 +496,7 @@ $config = array(
     'idpdisco.layout' => 'dropdown',
 
     /*
-     * Whether simpleSAMLphp should sign the response or the assertion in SAML 1.1 authentication
+     * Whether SimpleSAMLphp should sign the response or the assertion in SAML 1.1 authentication
      * responses.
      *
      * The default is to sign the assertion element, but that can be overridden by setting this
@@ -566,6 +615,26 @@ $config = array(
      * - 'file': Path to the XML file with the metadata.
      * - 'url': The URL to fetch metadata from. THIS IS ONLY FOR DEBUGGING - THERE IS NO CACHING OF THE RESPONSE.
      *
+     * MDX metadata handler:
+     * This metadata handler looks up for the metadata of an entity at the given MDX server.
+     * The MDX metadata handler defines the following options:
+     * - 'type': This is always 'mdx'.
+     * - 'server': URL of the MDX server (url:port). Mandatory.
+     * - 'validateFingerprint': The fingerprint of the certificate used to sign the metadata.
+     *                          You don't need this option if you don't want to validate the signature on the metadata. Optional.
+     * - 'cachedir': Directory where metadata can be cached. Optional.
+     * - 'cachelength': Maximum time metadata cah be cached, in seconds. Default to 24
+     *                  hours (86400 seconds). Optional.
+     *
+     * PDO metadata handler:
+     * This metadata handler looks up metadata of an entity stored in a database.
+     *
+     * Note: If you are using the PDO metadata handler, you must configure the database
+     * options in this configuration file.
+     *
+     * The PDO metadata handler defines the following options:
+     * - 'type': This is always 'pdo'.
+     *
      *
      * Examples:
      *
@@ -583,6 +652,15 @@ $config = array(
      *     array('type' => 'xml', 'file' => 'idp.example.org-idpMeta.xml'),
      *     ),
      *
+     * This example defines an mdx source.
+     * 'metadata.sources' => array(
+     *     array('type' => 'mdx', server => 'http://mdx.server.com:8080', 'cachedir' => '/var/simplesamlphp/mdx-cache', 'cachelength' => 86400)
+     *     ),
+     *
+     * This example defines an pdo source.
+     * 'metadata.sources' => array(
+     *     array('type' => 'pdo')
+     *     ),
      *
      * Default:
      * 'metadata.sources' => array(
@@ -595,7 +673,7 @@ $config = array(
 
 
     /*
-     * Configure the datastore for simpleSAMLphp.
+     * Configure the datastore for SimpleSAMLphp.
      *
      * - 'phpsession': Limited datastore, which uses the PHP session.
      * - 'memcache': Key-value datastore, based on memcache.
@@ -625,12 +703,12 @@ $config = array(
     /*
      * The prefix we should use on our tables.
      */
-    'store.sql.prefix' => 'simpleSAMLphp',
+    'store.sql.prefix' => 'SimpleSAMLphp',
 
 
     /*
-     * Configuration for the MemcacheStore class. This allows you to store
-     * multiple redudant copies of sessions on different memcache servers.
+     * Configuration for the 'memcache' session store. This allows you to store
+     * multiple redundant copies of sessions on different memcache servers.
      *
      * 'memcache_store.servers' is an array of server groups. Every data
      * item will be mirrored in every server group.
@@ -651,7 +729,7 @@ $config = array(
      *  - 'timeout': The timeout for this server. By default, the timeout
      *    is 3 seconds.
      *
-     * Example of redudant configuration with load balancing:
+     * Example of redundant configuration with load balancing:
      * This configuration makes it possible to lose both servers in the
      * a-group or both servers in the b-group without losing any sessions.
      * Note that sessions will be lost if one server is lost from both the
@@ -686,6 +764,17 @@ $config = array(
     ),
 
 
+    /*
+     * This value allows you to set a prefix for memcache-keys. The default
+     * for this value is 'SimpleSAMLphp', which is fine in most cases.
+     *
+     * When running multiple instances of SSP on the same host, and more
+     * than one instance is using memcache, you probably want to assign
+     * a unique value per instance to this setting to avoid data collision.
+     */
+    'memcache_store.prefix' => null,
+
+
     /*
      * This value is the duration data should be stored in memcache. Data
      * will be dropped from the memcache servers when this time expires.
@@ -737,25 +826,26 @@ $config = array(
 
     /*
      * Array of domains that are allowed when generating links or redirections
-     * to URLs. simpleSAMLphp will use this option to determine whether to
+     * to URLs. SimpleSAMLphp will use this option to determine whether to
      * to consider a given URL valid or not, but you should always validate
      * URLs obtained from the input on your own (i.e. ReturnTo or RelayState
      * parameters obtained from the $_REQUEST array).
      *
-     * Set to NULL to disable checking of URLs.
-     *
-     * simpleSAMLphp will automatically add your own domain (either by checking
-     * it dinamically, or by using the domain defined in the 'baseurlpath'
+     * SimpleSAMLphp will automatically add your own domain (either by checking
+     * it dynamically, or by using the domain defined in the 'baseurlpath'
      * directive, the latter having precedence) to the list of trusted domains,
      * in case this option is NOT set to NULL. In that case, you are explicitly
-     * telling simpleSAMLphp to verify URLs.
+     * telling SimpleSAMLphp to verify URLs.
      *
      * Set to an empty array to disallow ALL redirections or links pointing to
-     * an external URL other than your own domain.
+     * an external URL other than your own domain. This is the default behaviour.
+     *
+     * Set to NULL to disable checking of URLs. DO NOT DO THIS UNLESS YOU KNOW
+     * WHAT YOU ARE DOING!
      *
      * Example:
      *   'trusted.url.domains' => array('sp.example.com', 'app.example.com'),
      */
-    'trusted.url.domains' => null,
+    'trusted.url.domains' => array(),
 
 );
