@@ -25,7 +25,7 @@
  * elements of the state array.
  *
  * @author Olav Morken, UNINETT AS.
- * @package simpleSAMLphp
+ * @package SimpleSAMLphp
  */
 class SimpleSAML_Auth_State {
 
@@ -91,6 +91,44 @@ class SimpleSAML_Auth_State {
 	private static $stateTimeout = NULL;
 
 
+	/**
+	 * Get the persistent authentication state from the state array.
+	 *
+	 * @param array $state The state array to analyze.
+	 * @return array The persistent authentication state.
+	 */
+	public static function getPersistentAuthData(array $state)
+	{
+		// save persistent authentication data
+		$persistent = array();
+
+		if (array_key_exists('PersistentAuthData', $state)) {
+			foreach ($state['PersistentAuthData'] as $key) {
+				if (isset($state[$key])) {
+					$persistent[$key] = $state[$key];
+				}
+			}
+		}
+
+		// add those that should always be included
+		$mandatory = array(
+			'Attributes',
+			'Expire',
+			'LogoutState',
+			'AuthInstant',
+			'RememberMe',
+			'saml:sp:NameID'
+		);
+		foreach ($mandatory as $key) {
+			if (isset($state[$key])) {
+				$persistent[$key] = $state[$key];
+			}
+		}
+
+		return $persistent;
+	}
+
+
 	/**
 	 * Retrieve the ID of a state array.
 	 *
@@ -105,17 +143,17 @@ class SimpleSAML_Auth_State {
 		assert('is_bool($rawId)');
 
 		if (!array_key_exists(self::ID, $state)) {
-			$state[self::ID] = SimpleSAML_Utilities::generateID();
+			$state[self::ID] = SimpleSAML\Utils\Random::generateID();
 		}
 
 		$id = $state[self::ID];
 
 		if ($rawId || !array_key_exists(self::RESTART, $state)) {
-			/* Either raw ID or no restart URL. In any case, return the raw ID. */
+			// Either raw ID or no restart URL. In any case, return the raw ID.
 			return $id;
 		}
 
-		/* We have a restart URL. Return the ID with that URL. */
+		// We have a restart URL. Return the ID with that URL.
 		return $id . ':' . $state[self::RESTART];
 	}
 
@@ -154,10 +192,10 @@ class SimpleSAML_Auth_State {
 		$return = self::getStateId($state, $rawId);
 		$id = $state[self::ID];
 
-		/* Save stage. */
+		// Save stage
 		$state[self::STAGE] = $stage;
 
-		/* Save state. */
+		// Save state
 		$serializedState = serialize($state);
 		$session = SimpleSAML_Session::getSessionFromRequest();
 		$session->setData('SimpleSAML_Auth_State', $id, $serializedState, self::getStateTimeout());
@@ -210,13 +248,13 @@ class SimpleSAML_Auth_State {
 		assert('is_bool($allowMissing)');
 		SimpleSAML_Logger::debug('Loading state: ' . var_export($id, TRUE));
 
-		$sid = SimpleSAML_Utilities::parseStateID($id);
+		$sid = self::parseStateID($id);
 
 		$session = SimpleSAML_Session::getSessionFromRequest();
 		$state = $session->getData('SimpleSAML_Auth_State', $sid['id']);
 
 		if ($state === NULL) {
-			/* Could not find saved data. */
+			// Could not find saved data
 			if ($allowMissing) {
 				return NULL;
 			}
@@ -225,7 +263,7 @@ class SimpleSAML_Auth_State {
 				throw new SimpleSAML_Error_NoState();
 			}
 
-			SimpleSAML_Utilities::redirectTrustedURL($sid['url']);
+			\SimpleSAML\Utils\HTTP::redirectUntrustedURL($sid['url']);
 		}
 
 		$state = unserialize($state);
@@ -233,7 +271,7 @@ class SimpleSAML_Auth_State {
 		assert('array_key_exists(self::ID, $state)');
 		assert('array_key_exists(self::STAGE, $state)');
 
-		/* Verify stage. */
+		// Verify stage
 		if ($state[self::STAGE] !== $stage) {
 			/* This could be a user trying to bypass security, but most likely it is just
 			 * someone using the back-button in the browser. We try to restart the
@@ -249,7 +287,7 @@ class SimpleSAML_Auth_State {
 				throw new Exception($msg);
 			}
 
-			SimpleSAML_Utilities::redirectTrustedURL($sid['url']);
+			\SimpleSAML\Utils\HTTP::redirectUntrustedURL($sid['url']);
 		}
 
 		return $state;
@@ -267,7 +305,7 @@ class SimpleSAML_Auth_State {
 		assert('is_array($state)');
 
 		if (!array_key_exists(self::ID, $state)) {
-			/* This state hasn't been saved. */
+			// This state hasn't been saved
 			return;
 		}
 
@@ -289,15 +327,15 @@ class SimpleSAML_Auth_State {
 
 		if (array_key_exists(self::EXCEPTION_HANDLER_URL, $state)) {
 
-			/* Save the exception. */
+			// Save the exception
 			$state[self::EXCEPTION_DATA] = $exception;
 			$id = self::saveState($state, self::EXCEPTION_STAGE);
 
-			/* Redirect to the exception handler. */
-			SimpleSAML_Utilities::redirectTrustedURL($state[self::EXCEPTION_HANDLER_URL], array(self::EXCEPTION_PARAM => $id));
+			// Redirect to the exception handler
+			\SimpleSAML\Utils\HTTP::redirectTrustedURL($state[self::EXCEPTION_HANDLER_URL], array(self::EXCEPTION_PARAM => $id));
 
 		} elseif (array_key_exists(self::EXCEPTION_HANDLER_FUNC, $state)) {
-			/* Call the exception handler. */
+			// Call the exception handler
 			$func = $state[self::EXCEPTION_HANDLER_FUNC];
 			assert('is_callable($func)');
 
@@ -325,7 +363,7 @@ class SimpleSAML_Auth_State {
 
 		if ($id === NULL) {
 			if (!array_key_exists(self::EXCEPTION_PARAM, $_REQUEST)) {
-				/* No exception. */
+				// No exception
 				return NULL;
 			}
 			$id = $_REQUEST[self::EXCEPTION_PARAM];
@@ -337,6 +375,26 @@ class SimpleSAML_Auth_State {
 		return $state;
 	}
 
-}
 
-?>
\ No newline at end of file
+	/**
+	 * Get the ID and (optionally) a URL embedded in a StateID, in the form 'id:url'.
+	 *
+	 * @param string $stateId The state ID to use.
+	 *
+	 * @return array A hashed array with the ID and the URL (if any), in the 'id' and 'url' keys, respectively. If
+	 * there's no URL in the input parameter, NULL will be returned as the value for the 'url' key.
+	 *
+	 * @author Andreas Solberg, UNINETT AS <andreas.solberg@uninett.no>
+	 * @author Jaime Perez, UNINETT AS <jaime.perez@uninett.no>
+	 */
+	public static function parseStateID($stateId) {
+		$tmp = explode(':', $stateId, 2);
+		$id = $tmp[0];
+		$url = null;
+		if (count($tmp) === 2) {
+			$url = $tmp[1];
+		}
+		return array('id' => $id, 'url' => $url);
+	}
+
+}
