@@ -4,8 +4,8 @@
  * The Shibboleth 1.3 Authentication Request. Not part of SAML 1.1, 
  * but an extension using query paramters no XML.
  *
- * @author Andreas kre Solberg, UNINETT AS. <andreas.solberg@uninett.no>
- * @package simpleSAMLphp
+ * @author Andreas Åkre Solberg, UNINETT AS. <andreas.solberg@uninett.no>
+ * @package SimpleSAMLphp
  */
 class SimpleSAML_XML_Shib13_AuthnRequest {
 
@@ -27,14 +27,10 @@ class SimpleSAML_XML_Shib13_AuthnRequest {
 		return $this->issuer;
 	}
 
-	public function createRedirect($destination, $shire = NULL) {
+	public function createRedirect($destination, $shire) {
 		$metadata = SimpleSAML_Metadata_MetaDataStorageHandler::getMetadataHandler();
 		$idpmetadata = $metadata->getMetaDataConfig($destination, 'shib13-idp-remote');
 
-		if ($shire === NULL) {
-			$shire = $metadata->getGenerated('AssertionConsumerService', 'shib13-sp-hosted');
-		}
-
 		$desturl = $idpmetadata->getDefaultEndpoint('SingleSignOnService', array('urn:mace:shibboleth:1.0:profiles:AuthnRequest'));
 		$desturl = $desturl['Location'];
 
@@ -48,5 +44,3 @@ class SimpleSAML_XML_Shib13_AuthnRequest {
 	}
 
 }
-
-?>
\ No newline at end of file
