@@ -1,9 +1,9 @@
 <?php
 /**
- * ADFS PRP IDP protocol support for simpleSAMLphp.
+ * ADFS PRP IDP protocol support for SimpleSAMLphp.
  *
  * @author Hans Zandbelt, SURFnet bv, <hans.zandbelt@surfnet.nl>
- * @package simpleSAMLphp
+ * @package SimpleSAMLphp
  */
 
 SimpleSAML_Logger::info('ADFS - IdP.prp: Accessing ADFS IdP endpoint prp');
@@ -21,10 +21,8 @@ if (isset($_GET['wa'])) {
 	assert('FALSE');		
 } elseif(isset($_GET['assocId'])) {
 	// logout response from ADFS SP
-	$assocId = $_GET['assocId']; /* Association ID of the SP that sent the logout response. */
-	$relayState = $_GET['relayState']; /* Data that was sent in the logout request to the SP. Can be null. */
+	$assocId = $_GET['assocId']; // Association ID of the SP that sent the logout response
+	$relayState = $_GET['relayState']; // Data that was sent in the logout request to the SP. Can be null
 	$logoutError = NULL; /* NULL on success, or an instance of a SimpleSAML_Error_Exception on failure. */
 	$idp->handleLogoutResponse($assocId, $relayState, $logoutError);
 }
-
-?>
