@@ -5,7 +5,7 @@
  * certificate validation against an LDAP directory.
  *
  * @author Emmanuel Dreyfus <manu@netbsd.org>
- * @package simpleSAMLphp
+ * @package SimpleSAMLphp
  */
 class sspmod_authX509_Auth_Source_X509userCert extends SimpleSAML_Auth_Source {
 
@@ -126,7 +126,7 @@ class sspmod_authX509_Auth_Source_X509userCert extends SimpleSAML_Auth_Source {
 		    ($_SERVER['SSL_CLIENT_CERT'] == '')) {
 			$state['authX509.error'] = "NOCERT";
 			$this->authFailed($state);
-			assert('FALSE'); /* NOTREACHED */
+			assert('FALSE'); // NOTREACHED
 			return;
 		}
 
@@ -137,7 +137,7 @@ class sspmod_authX509_Auth_Source_X509userCert extends SimpleSAML_Auth_Source {
 			$state['authX509.error'] = "INVALIDCERT";
 			$this->authFailed($state);
 
-			assert('FALSE'); /* NOTREACHED */
+			assert('FALSE'); // NOTREACHED
 			return;
 		}
 
