@@ -17,7 +17,7 @@
  * </code>
  *
  * @author  Olav Morken <olav.morken@uninett.no>
- * @package simpleSAMLphp
+ * @package SimpleSAMLphp
  */
 class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
 {
@@ -199,7 +199,7 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
     {
         assert('is_string($data)');
 
-        $secretSalt = SimpleSAML_Utilities::getSecretSalt();
+        $secretSalt = SimpleSAML\Utils\Config::getSecretSalt();
 
         return sha1($secretSalt . $data . $secretSalt) . ':' . $data;
     }
@@ -272,14 +272,14 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
             'httponly' => FALSE,
         );
 
-        if (SimpleSAML_Utilities::isHTTPS()) {
-            /* Enable secure cookie for https-requests. */
+        if (\SimpleSAML\Utils\HTTP::isHTTPS()) {
+            // Enable secure cookie for https-requests
             $params['secure'] = true;
         } else {
             $params['secure'] = false;
         }
 
-        SimpleSAML_Utilities::setCookie($name, $value, $params, FALSE);
+        \SimpleSAML\Utils\HTTP::setCookie($name, $value, $params, FALSE);
     }
 
 }
