@@ -1,16 +1,16 @@
 <?php
 
 
-/* Load simpleSAMLphp, configuration */
+// Load SimpleSAMLphp, configuration
 $config = SimpleSAML_Configuration::getInstance();
 $session = SimpleSAML_Session::getSessionFromRequest();
 
-/* Check if valid local session exists.. */
+// Check if valid local session exists
 if ($config->getBoolean('admin.protectindexpage', false)) {
-	SimpleSAML_Utilities::requireAdmin();
+    SimpleSAML\Utils\Auth::requireAdmin();
 }
-$loginurl = SimpleSAML_Utilities::getAdminLoginURL();
-$isadmin = SimpleSAML_Utilities::isAdmin();
+$loginurl = SimpleSAML\Utils\Auth::getAdminLoginURL();
+$isadmin = SimpleSAML\Utils\Auth::isAdmin();
 
 
 
@@ -28,22 +28,6 @@ $links_auth[] = array(
 	'text' => '{core:frontpage:authtest}',
 );
 
-
-if ($config->getValue('enable.saml20-sp') === true)
-	$links_auth[] = array(
-		'href' => SimpleSAML_Utilities::getBaseURL() . 'example-simple/saml2-example.php',
-		'text' => '{core:frontpage:link_saml2example}',
-		'deprecated' => TRUE,
-	);
-
-if ($config->getValue('enable.shib13-sp') === true)
-	$links_auth[] = array(
-		'href' => SimpleSAML_Utilities::getBaseURL() . 'example-simple/shib13-example.php',
-		'text' => '{core:frontpage:link_shib13example}',
-		'deprecated' => TRUE,
-	);
-
-
 $allLinks = array(
 	'links'      => &$links,
 	'welcome'    => &$links_welcome,
