@@ -3,7 +3,6 @@
 if (!isset($_REQUEST['id'])) {
 	throw new SimpleSAML_Error_BadRequest('Missing required parameter: id');
 }
-$id = (string)$_REQUEST['id'];
 
 if (isset($_REQUEST['type'])) {
 	$type = (string)$_REQUEST['type'];
@@ -19,17 +18,11 @@ if ($type !== 'embed' && $type !== 'async') {
 	SimpleSAML_Stats::log('core:idp:logout-iframe:page', array('type' => $type));
 }
 
-// sanitize the input
-$sid = SimpleSAML_Utilities::parseStateID($id);
-if (!is_null($sid['url'])) {
-	SimpleSAML_Utilities::checkURLAllowed($sid['url']);
-}
-
-$state = SimpleSAML_Auth_State::loadState($id, 'core:Logout-IFrame');
+$state = SimpleSAML_Auth_State::loadState($_REQUEST['id'], 'core:Logout-IFrame');
 $idp = SimpleSAML_IdP::getByState($state);
 
 if ($type !== 'init') {
-	/* Update association state. */
+	// Update association state
 
 	$associations = $idp->getAssociations();
 
@@ -37,7 +30,7 @@ if ($type !== 'init') {
 
 		$spId = sha1($assocId);
 
-		/* Move SPs from 'onhold' to 'inprogress'. */
+		// Move SPs from 'onhold' to 'inprogress'
 		if ($sp['core:Logout-IFrame:State'] === 'onhold') {
 			$sp['core:Logout-IFrame:State'] = 'inprogress';
 		}
@@ -114,5 +107,6 @@ $t->data['id'] = $id;
 $t->data['type'] = $type;
 $t->data['from'] = $state['core:Logout-IFrame:From'];
 $t->data['SPs'] = $state['core:Logout-IFrame:Associations'];
+$t->data['jquery'] = array('core' => TRUE, 'ui' => FALSE, 'css' => FALSE);
 $t->show();
 exit(0);
