@@ -16,7 +16,7 @@ if(!array_key_exists('header', $this->data)) {
 	$this->data['header'] = 'selectidp';
 }
 $this->data['header'] = $this->t($this->data['header']);
-$this->data['jquery'] = array('version' => '1.6', 'core' => TRUE, 'ui' => TRUE, 'css' => TRUE);
+$this->data['jquery'] = array('core' => TRUE, 'ui' => TRUE, 'css' => TRUE);
 
 $this->data['head'] = '<link rel="stylesheet" media="screen" type="text/css" href="' . SimpleSAML_Module::getModuleUrl('discopower/style.css')  . '" />';
 
@@ -50,17 +50,6 @@ if (!empty($faventry)) $this->data['autofocus'] = 'favouritesubmit';
 
 $this->includeAtTemplateBase('includes/header.php');
 
-// foreach ($this->data['idplist'] AS $slist) {
-// 	foreach ($slist AS $idpentry) {
-// 		if (isset($idpentry['name']))
-// 			$this->includeInlineTranslation('idpname_' . $idpentry['entityid'], $idpentry['name']);
-// 		if (isset($idpentry['description']))
-// 			$this->includeInlineTranslation('idpdesc_' . $idpentry['entityid'], $idpentry['description']);
-// 	}
-// }
-// 
-
-
 function showEntry($t, $metadata, $favourite = FALSE) {
 	
 	$basequerystring = '?' . 
@@ -73,21 +62,11 @@ function showEntry($t, $metadata, $favourite = FALSE) {
 	
 	$html .= '' . htmlspecialchars(getTranslatedName($t, $metadata)) . '';
 
-	#print_r($metadata['scopes']); 
-
-	// if (!empty($idpentry['description'])) {
-	// 	$html .= '	<p>' . htmlspecialchars($t->t('idpdesc_' . $metadata['entityid'])) . '<br />';
-	// }
-	
 	if(array_key_exists('icon', $metadata) && $metadata['icon'] !== NULL) {
-		$iconUrl = SimpleSAML_Utilities::resolveURL($metadata['icon']);
+		$iconUrl = \SimpleSAML\Utils\HTTP::resolveURL($metadata['icon']);
 		$html .= '<img alt="Icon for identity provider" class="entryicon" src="' . htmlspecialchars($iconUrl) . '" />';
 	}
-	
-	// $html .= '<input id="preferredidp" type="submit" name="idp_' .
-	// 	htmlspecialchars($metadata['entityid']) . '" value="' .
-	// 	$t->t('select') . '" /></p>';
-	
+
 	$html .= '</a>';
 	
 	return $html;
@@ -101,10 +80,9 @@ function showEntry($t, $metadata, $favourite = FALSE) {
 <?php
 
 function getTranslatedName($t, $metadata) {
-#	if (is_null($metadata)) throw new Exception();
 	if (isset($metadata['UIInfo']['DisplayName'])) {
 		$displayName = $metadata['UIInfo']['DisplayName'];
-		assert('is_array($displayName)'); // Should always be an array of language code -> translation.
+		assert('is_array($displayName)'); // Should always be an array of language code -> translation
 		if (!empty($displayName)) {
 			return $t->getTranslation($displayName);
 		}
@@ -176,10 +154,6 @@ foreach( $this->data['idplist'] AS $tab => $slist) {
 	echo '<div id="' . $tab . '">';
 
 	if (!empty($slist)) {
-		
-		// echo 'Favourite :: ' . $this->data['preferredidp']; 
-		// echo '<pre>';
-		// print_r($slist); exit;
 
 		echo('	<div class="inlinesearch">');
 		echo('	<p>Incremental search...</p>');
@@ -210,4 +184,4 @@ foreach( $this->data['idplist'] AS $tab => $slist) {
 </div>
 
 		
-<?php $this->includeAtTemplateBase('includes/footer.php'); ?>
+<?php $this->includeAtTemplateBase('includes/footer.php');
