@@ -24,4 +24,4 @@ if (!empty($this->data['results'])) {
 }
 ?>
 </pre>
-<?php $this->includeAtTemplateBase('includes/footer.php'); ?>
\ No newline at end of file
+<?php $this->includeAtTemplateBase('includes/footer.php');
