@@ -5,7 +5,7 @@
  *
  * @author Mathias Meisfjordskar, University of Oslo.
  *         <mathias.meisfjordskar@usit.uio.no>
- * @package simpleSAMLphp
+ * @package SimpleSAMLphp
  */
 $this->includeAtTemplateBase('includes/header.php');
 ?>
@@ -17,4 +17,4 @@ $url = SimpleSAML_Module::getModuleURL('negotiate/enable.php');
 
 <?php echo $this->t('{negotiate:negotiate:info_post}'); ?>
 
-<?php $this->includeAtTemplateBase('includes/footer.php'); ?>
+<?php $this->includeAtTemplateBase('includes/footer.php');
