@@ -7,7 +7,6 @@
  * Auth_OpenID_Consumer class.
  *
  * @package simpleSAMLphp
- * @version $Id$
  */
 class sspmod_openid_SessionStore {
 
@@ -20,7 +19,7 @@ class sspmod_openid_SessionStore {
 	public function get($key) {
 		assert('is_string($key)');
 
-		$session = SimpleSAML_Session::getInstance();
+		$session = SimpleSAML_Session::getSessionFromRequest();
 		return $session->getData('openid.session', $key);
 	}
 
@@ -34,7 +33,7 @@ class sspmod_openid_SessionStore {
 	public function set($key, $value) {
 		assert('is_string($key)');
 
-		$session = SimpleSAML_Session::getInstance();
+		$session = SimpleSAML_Session::getSessionFromRequest();
 		$session->setData('openid.session', $key, $value);
 	}
 
@@ -47,7 +46,7 @@ class sspmod_openid_SessionStore {
 	public function del($key) {
 		assert('is_string($key)');
 
-		$session = SimpleSAML_Session::getInstance();
+		$session = SimpleSAML_Session::getSessionFromRequest();
 		$session->deleteData('openid.session', $key);
 	}
 
