@@ -4,7 +4,7 @@
  * This script displays a page to the user, which requests that the user
  * authorizes the release of attributes.
  *
- * @package simpleSAMLphp
+ * @package SimpleSAMLphp
  */
 
 SimpleSAML_Logger::info('PreProdWarning - Showing warning to user');
@@ -12,20 +12,12 @@ SimpleSAML_Logger::info('PreProdWarning - Showing warning to user');
 if (!array_key_exists('StateId', $_REQUEST)) {
 	throw new SimpleSAML_Error_BadRequest('Missing required StateId query parameter.');
 }
-
 $id = $_REQUEST['StateId'];
-
-// sanitize the input
-$sid = SimpleSAML_Utilities::parseStateID($id);
-if (!is_null($sid['url'])) {
-	SimpleSAML_Utilities::checkURLAllowed($sid['url']);
-}
-
 $state = SimpleSAML_Auth_State::loadState($id, 'warning:request');
 
 
 if (array_key_exists('yes', $_REQUEST)) {
-	/* The user has pressed the yes-button. */
+	// The user has pressed the yes-button
 
 	SimpleSAML_Auth_ProcessingChain::resumeProcessing($state);
 }
@@ -38,6 +30,3 @@ $t = new SimpleSAML_XHTML_Template($globalConfig, 'preprodwarning:warning.php');
 $t->data['yesTarget'] = SimpleSAML_Module::getModuleURL('preprodwarning/showwarning.php');
 $t->data['yesData'] = array('StateId' => $id);
 $t->show();
-
-
-?>
\ No newline at end of file
