@@ -7,7 +7,7 @@
  */
 
 if (!array_key_exists('PATH_INFO', $_SERVER)) {
-	throw new SimpleSAML_Error_BadRequest('Missing authentication source id in logout URL');
+	throw new SimpleSAML_Error_BadRequest('Missing authentication source ID in logout URL');
 }
 
 $sourceId = substr($_SERVER['PATH_INFO'], 1);
@@ -20,12 +20,22 @@ if (!($source instanceof sspmod_saml_Auth_Source_SP)) {
 	throw new SimpleSAML_Error_Exception('Source type changed?');
 }
 
-$binding = SAML2_Binding::getCurrentBinding();
+try {
+    $binding = SAML2_Binding::getCurrentBinding();
+} catch (Exception $e) { // TODO: look for a specific exception
+    // This is dirty. Instead of checking the message of the exception, SAML2_Binding::getCurrentBinding() should throw
+    // an specific exception when the binding is unknown, and we should capture that here
+    if ($e->getMessage() === 'Unable to find the current binding.') {
+        throw new SimpleSAML_Error_Error('SLOSERVICEPARAMS', $e, 400);
+    } else {
+        throw $e; // do not ignore other exceptions!
+    }
+}
 $message = $binding->receive();
 
 $idpEntityId = $message->getIssuer();
 if ($idpEntityId === NULL) {
-	/* Without an issuer we have no way to respond to the message. */
+	// Without an issuer we have no way to respond to the message.
 	throw new SimpleSAML_Error_BadRequest('Received message on logout endpoint without issuer.');
 }
 
@@ -38,7 +48,7 @@ $spMetadata = $source->getMetadata();
 sspmod_saml_Message::validateMessage($idpMetadata, $spMetadata, $message);
 
 $destination = $message->getDestination();
-if ($destination !== NULL && $destination !== SimpleSAML_Utilities::selfURLNoQuery()) {
+if ($destination !== NULL && $destination !== \SimpleSAML\Utils\HTTP::getSelfURLNoQuery()) {
 	throw new SimpleSAML_Error_Exception('Destination in logout message is wrong.');
 }
 
@@ -46,7 +56,7 @@ if ($message instanceof SAML2_LogoutResponse) {
 
 	$relayState = $message->getRelayState();
 	if ($relayState === NULL) {
-		/* Somehow, our RelayState has been lost. */
+		// Somehow, our RelayState has been lost.
 		throw new SimpleSAML_Error_BadRequest('Missing RelayState in logout response.');
 	}
 
@@ -54,12 +64,6 @@ if ($message instanceof SAML2_LogoutResponse) {
 		SimpleSAML_Logger::warning('Unsuccessful logout. Status was: ' . sspmod_saml_Message::getResponseError($message));
 	}
 
-	// sanitize the input
-	$sid = SimpleSAML_Utilities::parseStateID($relayState);
-	if (!is_null($sid['url'])) {
-		SimpleSAML_Utilities::checkURLAllowed($sid['url']);
-	}
-
 	$state = SimpleSAML_Auth_State::loadState($relayState, 'saml:slosent');
 	$state['saml:sp:LogoutStatus'] = $message->getStatus();
 	SimpleSAML_Auth_Source::completeLogout($state);
