@@ -3,7 +3,7 @@
 /**
  * Class implementing the access checker function for the statistics module.
  *
- * @package simpleSAMLphp
+ * @package SimpleSAMLphp
  */
 class sspmod_statistics_AccessCheck {
 
@@ -28,7 +28,7 @@ class sspmod_statistics_AccessCheck {
 			return;
 		}
 
-		if (SimpleSAML_Utilities::isAdmin()) {
+		if (SimpleSAML\Utils\Auth::isAdmin()) {
 			// User logged in as admin. OK.
 			SimpleSAML_Logger::debug('Statistics auth - logged in as admin, access granted');
 			return;
@@ -36,10 +36,10 @@ class sspmod_statistics_AccessCheck {
 
 		if (!isset($authsource)) {
 			// If authsource is not defined, init admin login.
-			SimpleSAML_Utilities::requireAdmin();
+            SimpleSAML\Utils\Auth::requireAdmin();
 		}
 
-		/* We are using an authsource for login. */
+		// We are using an authsource for login.
 
 		$as = new SimpleSAML_Auth_Simple($authsource);
 		$as->requireAuth();
