@@ -1,12 +1,11 @@
 <?php
 /*
  * @author Andreas Åkre Solberg <andreas.solberg@uninett.no>
- * @package simpleSAMLphp
- * @version $Id$
+ * @package SimpleSAMLphp
  */
 class sspmod_statistics_DateHandler {
 
-	private $offset;
+	protected $offset;
 
 	/**
 	 * Constructor
@@ -28,8 +27,6 @@ class sspmod_statistics_DateHandler {
 	}
 
 	public function fromSlot($slot, $slotsize) {
-		// echo("slot $slot slotsize $slotsize offset  " . $this->offset);
-		// throw new Exception();
 		$temp = $slot*$slotsize - $this->offset;
 		$dst = $this->getDST($temp);
 		return $slot*$slotsize - $this->offset - $dst;
@@ -50,16 +47,4 @@ class sspmod_statistics_DateHandler {
 		$text .= $this->prettyDateSlot($to, $slotsize, $dateformat);
 		return $text;
 	}
-
 }
-
-// 	$datestr = substr($logline,0,$datenumbers);
-// 	#$datestr = substr($logline,0,23);
-// 	$timestamp = parse15($datestr) + $offset;
-// 	$restofline = substr($logline,$datenumbers+1);
-// 	$restcols = split(' ', $restofline);
-// 	$action = $restcols[5];
-	
-// 	print_r($timestamp);
-// 	print_r($restcols); if ($i++ > 5) exit;
-
