@@ -6,4 +6,4 @@
 
 <h2><?php echo $this->t('errorreport_header'); ?></h2>
 <p><?php echo $this->t('errorreport_text'); ?></p>
-<?php $this->includeAtTemplateBase('includes/footer.php'); ?>
\ No newline at end of file
+<?php $this->includeAtTemplateBase('includes/footer.php');
