@@ -5,7 +5,7 @@
  * And when the artifact is found, it sends a SAML2_ArtifactResponse.
  *
  * @author Danny Bollaert, UGent AS. <danny.bollaert@ugent.be>
- * @package simpleSAMLphp
+ * @package SimpleSAMLphp
  */
 
 require_once('../../_include.php');
@@ -29,7 +29,18 @@ if ($store === FALSE) {
 }
 
 $binding = new SAML2_SOAP();
-$request = $binding->receive();
+try {
+    $request = $binding->receive();
+} catch (Exception $e) { // TODO: look for a specific exception
+    // This is dirty. Instead of checking the message of the exception, SAML2_Binding::getCurrentBinding() should throw
+    // an specific exception when the binding is unknown, and we should capture that here. Also note that the exception
+    // message here is bogus!
+    if ($e->getMessage() === 'Invalid message received to AssertionConsumerService endpoint.') {
+        throw new SimpleSAML_Error_Error('ARSPARAMS', $e, 400);
+    } else {
+        throw $e; // do not ignore other exceptions!
+    }
+}
 if (!($request instanceof SAML2_ArtifactResolve)) {
 	throw new Exception('Message received on ArtifactResolutionService wasn\'t a ArtifactResolve request.');
 }
@@ -43,8 +54,7 @@ $responseData = $store->get('artifact', $artifact);
 $store->delete('artifact', $artifact);
 
 if ($responseData !== NULL) {
-	$document = new DOMDocument();
-	$document->loadXML($responseData);
+	$document = SAML2_DOMDocumentFactory::fromString($responseData);
 	$responseXML = $document->firstChild;
 } else {
 	$responseXML = NULL;
